summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmpovrayparser.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmpovrayparser.h')
-rw-r--r--kpovmodeler/pmpovrayparser.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kpovmodeler/pmpovrayparser.h b/kpovmodeler/pmpovrayparser.h
index 72306508..c00bdfbe 100644
--- a/kpovmodeler/pmpovrayparser.h
+++ b/kpovmodeler/pmpovrayparser.h
@@ -160,14 +160,14 @@ private:
/**
* Looks for child objects, parses them and appends them to the parent
* object. If parent is 0, all objects are appended to the result list.
*
* If max is > 0, then the maximum number of parsed objects is max.
*
* Returns true if there where no objects or parsing was successful.
*/
- bool parseChildObjects( PMCompositeObject* parent, int max = -1 );
+ bool parseChildObjects( PMCompositeObject* tqparent, int max = -1 );
/**
@@ -179,7 +179,7 @@ private:
* If t is not a single character token, set tokenName to the token
* name (like "box", "sphere" ...)
*/
- bool parseToken( int t, const TQString& tokenName = TQString::null );
+ bool parseToken( int t, const TQString& tokenName = TQString() );
/**
* Parses an item of a vector, float or color expression
@@ -491,7 +491,7 @@ private:
/**
* Parse function for object keywords
*/
- bool parseObject( PMCompositeObject* parent );
+ bool parseObject( PMCompositeObject* tqparent );
// POV-Ray 3.5 objects
bool parseIsoSurface( PMIsoSurface* iso );
@@ -160,14 +160,14 @@ private:
/**
- * Looks for child objects, parses them and appends them to the parent
- * object. If parent is 0, all objects are appended to the result list.
+ * Looks for child objects, parses them and appends them to the tqparent
+ * object. If tqparent is 0, all objects are appended to the result list.
*
* If max is > 0, then the maximum number of parsed objects is max.